@@ -1,6 +1,7 @@
 # Copyright (c) 2014-2020 GeoSpock Ltd.
 
 import json
+import keyring
 import os
 import socket
 from pathlib import Path
@@ -25,24 +26,6 @@ class ConfigReaderAndWriter:
         self.config = None
         self.credentials = None
 
-    def encode(self, string):
-        encoded_chars = []
-        for i in range(len(string)):
-            key_c = self.KEY[i % len(self.KEY)]
-            encoded_c = chr(ord(string[i]) + ord(key_c) % 256)
-            encoded_chars.append(encoded_c)
-        encoded_string = "".join(encoded_chars)
-        return encoded_string
-
-    def decode(self, string):
-        decoded_chars = []
-        for i in range(len(string)):
-            key_c = self.KEY[i % len(self.KEY)]
-            decoded_c = chr(ord(string[i]) - ord(key_c) % 256)
-            decoded_chars.append(decoded_c)
-        decoded_string = "".join(decoded_chars)
-        return decoded_string
-
     def write_login(self, username: str, password: str, request_address: str):
         Path(self.GEOSPOCK_DIR).mkdir(parents=True, exist_ok=True)
 
@@ -55,25 +38,35 @@ class ConfigReaderAndWriter:
         else:
             current_config = dict()
         try:
-            current_config[self.profile] = dict(l=self.encode(username), p=self.encode(password),
-                                                request_address=request_address)
+            current_config[self.profile] = dict(request_address=request_address)
         except Exception:
-            raise CLIError("Could not generate configuration entry from provided username and password.")
+            raise CLIError("Could not generate configuration entry from provided request address.")
         with open(self.CONFIG_FILE, "w") as config_file_write:
             config_file_write.write(json.dumps(current_config, indent=4))
+        keyring.set_password("geospock", self.profile + "-username", username)
+        keyring.set_password("geospock", self.profile + "-password", password)
 
     def write_logout(self):
         if os.path.exists(self.CONFIG_FILE) and os.path.getsize(self.CONFIG_FILE) > 0:
+            current_config = dict()
             with open(self.CONFIG_FILE) as json_file:
                 try:
                     current_config = json.load(json_file)
                     current_config.pop(self.profile, None)
                 except json.JSONDecodeError:
                     raise CLIError(ConfigReaderAndWriter.MESSAGES["invalidConfig"])
-        else:
-            current_config = dict()
-        with open(self.CONFIG_FILE, "w") as config_file_write:
-            config_file_write.write(json.dumps(current_config, indent=4))
+            with open(self.CONFIG_FILE, "w") as config_file_write:
+                config_file_write.write(json.dumps(current_config, indent=4))
+        try:
+            keyring.delete_password("geospock", self.profile + "-username")
+            keyring.delete_password("geospock", self.profile + "-password")
+        except keyring.errors.PasswordDeleteError:
+            pass
+
+    def decode(self):
+        user = keyring.get_password("geospock", self.profile + "-username")
+        password = keyring.get_password("geospock", self.profile + "-password")
+        return user, password
 
     def write_to_config(self, client_id: str, audience: str, auth0url: str, request_address: str) -> None:
         Path(self.GEOSPOCK_DIR).mkdir(parents=True, exist_ok=True)
