@@ -23,8 +23,14 @@ def get_header(config_reader: ConfigReaderAndWriter, user: str, password: str, r
         raise CLIError(ConfigReaderAndWriter.MESSAGES["profileError"].format(config_reader.profile))
     elif config_reader.profile not in config_all and not request_address:
         raise CLIError(ConfigReaderAndWriter.MESSAGES["noInit"].format(config_reader.profile))
-    if not request_address:
+
+    # Get request address from argument, environment variable or config (in that order)
+    if not request_address and os.environ.get('GEOSPOCK_REQUEST_ADDRESS') is not None:
+        request_address = os.environ.get('GEOSPOCK_REQUEST_ADDRESS')
+    elif not request_address:
         request_address = config_reader.config["request_address"]
+
+    # If using GeoSpock 3.0
     if "auth0_url" in config_all[config_reader.profile]:
         all_credentials = config_reader.get_all_credentials_from_file()
         auth = Authorizer(config_reader)
@@ -46,12 +52,12 @@ def get_header(config_reader: ConfigReaderAndWriter, user: str, password: str, r
         return get_basic_auth_header(os.environ.get('GEOSPOCK_USER'),
                                      os.environ.get('GEOSPOCK_PASSWORD'),
                                      request_address)
-    elif "l" in config_all[config_reader.profile] and "p" in config_all[config_reader.profile]:
-        return get_basic_auth_header(config_reader.decode(config_all[config_reader.profile]["l"]),
-                                     config_reader.decode(config_all[config_reader.profile]["p"]),
-                                     request_address)
     else:
-        raise CLIError(ConfigReaderAndWriter.MESSAGES["insufficientLoginDetails"])
+        try:
+            username, password = config_reader.decode()
+            return get_basic_auth_header(username, password, request_address)
+        except Exception:
+            raise CLIError(ConfigReaderAndWriter.MESSAGES["insufficientLoginDetails"])
 
 
 def get_basic_auth_header(username: str, password: str, request_address: str) -> Tuple[dict, str]:
@@ -271,7 +277,10 @@ def process_parameters(parameters: dict, args: dict, command: str) -> Tuple[dict
                 click.echo("No file location provided for argument --{0}.".format(parameter["name"]))
             else:
                 file_contents = load_file(args[parameter["name"]])
-                new_args[parameter["internalName"]] = file_contents
+                if parameter["type"] == "String":
+                    new_args[parameter["internalName"]] = json.dumps(file_contents)
+                else:
+                    new_args[parameter["internalName"]] = file_contents
         elif "default" in parameter:
             new_args[parameter["internalName"]] = parameter["default"]
         elif ("subParams" in parameter and len(parameter["subParams"]) == 0) and parameter["required"]:
